@@ -1,7 +1,7 @@
 import logging
 import pathlib
 import yaml
-from dictdiffer import diff, patch, swap
+# from dictdiffer import diff, patch, swap
 from dataclasses import dataclass, asdict
 import dacite
 from dacite.exceptions import WrongTypeError, MissingValueError
@@ -65,94 +65,6 @@ class Params:
         file.save(data=asdict(self))
 
 
-@dataclass
-class Cat:
-    filename: str | None
-    translate: dict[str, list[str]] | None
-
-
-@dataclass
-class Data:
-    dir: str | None
-
-
-@dataclass
-class Loader:
-    cat: Cat
-    data: Data
-
-
-@dataclass
-class Geometry:
-    min_width: int | None
-    min_height: int | None
-
-
-@dataclass
-class AbstractWidget(Geometry):
-    pass
-
-
-@dataclass
-class ControlPanel(AbstractWidget):
-    button_width: int
-
-
-@dataclass
-class ObjectInfo(AbstractWidget):
-    items: dict[str, str] | None
-
-
-@dataclass
-class ReviewForm(AbstractWidget):
-    checkboxes: dict[str, str] | None
-
-
-@dataclass
-class ViewerElement(AbstractWidget):
-    search_mask: str
-
-
-@dataclass
-class Slider:
-    min_value: float | None
-    max_value: float | None
-    step: float | None
-    default_value: float | None
-
-
-@dataclass
-class Spec1D(ViewerElement):
-    slider: Slider
-
-
-@dataclass
-class Viewer(AbstractWidget):
-    image_cutout: ViewerElement
-    spec_2d: ViewerElement
-    spec_1d: Spec1D
-
-
-@dataclass
-class Config(Params):
-    loader: Loader
-    writer: None
-    control_panel: ControlPanel
-    object_info: ObjectInfo
-    review_form: ReviewForm
-    viewer: Viewer
-
-    @classmethod
-    def read(cls, file: LocalFile, path_to_default: str | None = None):
-        return super().read(file, path_to_default='default_config.yml')
-
-
-@dataclass
-class Cache(Params):
-    last_inspection_file: str | None
-    last_object_index: int | None
-
-
 def read_yaml(filename=None, in_dist=False) -> dict:
     if filename is None:
         return {}
