@@ -1,4 +1,4 @@
-from pyqtgraph.Qt import QtWidgets
+from qtpy import QtWidgets
 
 
 def get_widgets(layout: QtWidgets.QLayout):
