@@ -1,40 +1,49 @@
 import logging
 
-from astropy.coordinates import SkyCoord
+# from astropy.coordinates import SkyCoord
 
-from ..runtime import RuntimeData
+from ..runtime.appdata import AppData
 from .AbstractWidget import AbstractWidget
 
 
-from pyqtgraph.Qt import QtWidgets, QtCore
+from qtpy import QtWidgets, QtCore
 
 
 logger = logging.getLogger(__name__)
 
 
 class ObjectInfo(QtWidgets.QGroupBox, AbstractWidget):
-    def __init__(self, rd: RuntimeData, parent=None):
+    def __init__(self, rd: AppData, parent=None):
         self.cfg = rd.config.object_info
         super().__init__(rd=rd, cfg=self.cfg, parent=parent)
 
         self.setTitle('Object Information')
         self.setSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
 
-        grid = QtWidgets.QGridLayout()
-
         # display information about the object
-        self._labels = {}
+        self._labels = self.create_info_widgets(self.cfg.items.items())
 
-        if self.cfg.items:
-            for i, (cname, label) in enumerate(self.cfg.items.items()):
-                widget = QtWidgets.QLabel()
-                widget.setText(label)
-                widget.setHidden(True)
-                widget.setTextInteractionFlags(QtCore.Qt.TextSelectableByMouse)
-                self._labels[cname] = widget
-                grid.addWidget(widget, i + 1, 1, 1, 1)
+        self.init_ui()
 
-        self.setLayout(grid)
+    @staticmethod
+    def create_info_widgets(items) -> dict[str, QtWidgets.QLabel]:
+        if items is None:
+            return {}
+
+        info_widgets = {}
+        for i, (cname, label) in enumerate(items):
+            widget = QtWidgets.QLabel()
+            widget.setText(label)
+            widget.setHidden(True)
+            widget.setTextInteractionFlags(QtCore.Qt.TextSelectableByMouse)
+
+            info_widgets[cname] = widget
+
+        return info_widgets
+
+    def init_ui(self):
+        for i, widget in enumerate(self._labels.values()):
+            self.layout.addWidget(widget, i + 1, 1, 1, 1)
 
     def load_object(self):
         for cname, widget in self._labels.items():
