@@ -6,52 +6,42 @@ from astropy.io import fits
 from astropy.utils.decorators import lazyproperty
 
 import pyqtgraph as pg
-from pyqtgraph.Qt import QtCore, QtWidgets
+from qtpy import QtCore, QtWidgets
 
 from ..utils.params import read_yaml
 from ..utils import SmartSlider
 
 from .ViewerElement import ViewerElement
-from ..runtime import RuntimeData
+from ..runtime.appdata import AppData
 
 
 logger = logging.getLogger(__name__)
 
 
 class Spec1D(ViewerElement):
-    def __init__(self, rd: RuntimeData, parent=None):
+    def __init__(self, rd: AppData, parent=None):
         self.cfg = rd.config.viewer.spec_1d
         super().__init__(rd=rd, cfg=self.cfg, parent=parent)
 
         # load the list of spectral lines
-        # TODO: move to the runtime data
+        # TODO: move to the application data
         self._lines = read_yaml('default_lines.yml', in_dist=True)
 
-        grid = QtWidgets.QGridLayout()
-        grid.setContentsMargins(0, 0, 0, 0)
-
-        # add a label
+        # create a label
         self._label = QtWidgets.QLabel()
-        grid.addWidget(self._label, 1, 1)
 
-        # add a widget for the spectrum
+        # create a widget for the spectrum
         self._spec_1d_widget = pg.GraphicsLayoutWidget()
-        grid.addWidget(self._spec_1d_widget, 2, 1, 1, 3)
 
-        # add a redshift slider
+        # create a redshift slider
         self._z_slider = SmartSlider(QtCore.Qt.Horizontal, **asdict(self.cfg.slider))
         self._z_slider.valueChanged[int].connect(self._update_from_slider)
         self._z_slider.setToolTip('Slide to redshift.')
-        grid.addWidget(self._z_slider, 3, 1, 1, 1)
 
-        # add a line edit for changing the redshift
+        # create a line edit for changing the redshift
         self._redshift_editor = QtWidgets.QLineEdit()
         self._redshift_editor.returnPressed.connect(self._update_from_editor)
         self._redshift_editor.setMaximumWidth(120)
-        grid.addWidget(QtWidgets.QLabel('z = ', self), 3, 2, 1, 1)
-        grid.addWidget(self._redshift_editor, 3, 3, 1, 1)
-
-        self.setLayout(grid)
 
         # set up the plot
         self._spec_1d = self._spec_1d_widget.addPlot()
@@ -68,6 +58,15 @@ class Spec1D(ViewerElement):
 
             self._line_artists[line_name] = {'line': line, 'label': label}
 
+        self.init_ui()
+
+    def init_ui(self):
+        self.layout.addWidget(self._label, 1, 1)
+        self.layout.addWidget(self._spec_1d_widget, 2, 1, 1, 3)
+        self.layout.addWidget(self._z_slider, 3, 1, 1, 1)
+        self.layout.addWidget(QtWidgets.QLabel('z = ', self), 3, 2, 1, 1)
+        self.layout.addWidget(self._redshift_editor, 3, 3, 1, 1)
+
     @lazyproperty
     def _hdu(self):
         try:
@@ -107,7 +106,7 @@ class Spec1D(ViewerElement):
         for line_name, line_artist in self._line_artists.items():
             line_wave = self._lines['lambda'][line_name] * (1 + self._z_slider.value)
             line_artist['line'].setPos(line_wave)
-            line_artist['label'].setPos(line_wave, self._label_height)
+            line_artist['label'].setPos(QtCore.QPointF(line_wave, self._label_height))
 
     def _update_from_slider(self, index=None):
         if index is not None:
